//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCMFILE_H
#define WSCMFILE_H
#include <WScom.h>

class WSCmfile {

protected:
  char*      _buf;
  long       _seek_pt;
  long       _buf_len;

public:
  WSDLEX32 WSCmfile();
  WSDLEX32 virtual ~WSCmfile();

  WSDLEX32 long    open(void* data,long len);
  WSDLEX32 long    setBuf(void* data,long len);
  WSDLEX32 long    close();
  WSDLEX32 long    read(void*,long len);
  WSDLEX32 long    write(void*,long len);
  WSDLEX32 long    tell();
  WSDLEX32 long    getSize();

  WSDLEX32 WSCbool eof();
  WSDLEX32 long    seek(long addr);
  WSDLEX32 long    seekSet();
  WSDLEX32 long    seekEnd();
};
#endif
